==> io.janusproject.plugin-0.5.3-sources.jar: io/janusproject/util/ClassFinder.java <==
/*
 * $Id$
 *
 * SARL is an general-purpose agent programming language.
 * More details on http://www.sarl.io
 *
 * Copyright (C) 2014-2017 the original authors or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.janusproject.util;

import org.arakhne.afc.vmutil.ClassLoaderFinder;

import io.janusproject.kernel.services.jdk.logging.StandardLogService.LoggerCallerProvider;
import io.janusproject.services.logging.LogService;

/**
 * Uitility for finding a class.
 *
 * @author $Author: sgalland$
 * @version $FullVersion$
 * @mavengroupid $GroupId$
 * @mavenartifactid $ArtifactId$
 * @since 0.4.2
 */
public final class ClassFinder {

    private ClassFinder() {
        //
    }

    /**
     * Find the class with a search policiy.
     *
     * @param classname the name of the class.
     * @return the class.
     */
    public static Class<?> findClass(String classname) {
		Class<?> type = null;
		final ClassLoader loader = ClassLoaderFinder.findClassLoader();
		if (loader != null) {
			try {
				type = loader.loadClass(classname);
			} catch (ClassNotFoundException e) {
				//
			}
		}
		if (type == null) {
			try {
				type = ClassFinder.class.getClassLoader().loadClass(classname);
			} catch (ClassNotFoundException e) {
				//
			}
		}
		if (type == null) {
			try {
				type = Class.forName(classname);
			} catch (ClassNotFoundException e) {
				//
			}
		}
		if (type != null && !LogService.class.isAssignableFrom(type)
				&& !LoggerCallerProvider.class.isAssignableFrom(type)) {
			return type;
		}
		return null;
    }

}

==> io.janusproject.plugin-0.10.1-sources.jar: io/janusproject/util/ClassFinder.java <==
/*
 * $Id$
 *
 * SARL is an general-purpose agent programming language.
 * More details on http://www.sarl.io
 *
 * Copyright (C) 2014-2019 the original authors or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.janusproject.util;

import org.arakhne.afc.vmutil.ClassLoaderFinder;

import io.janusproject.services.logging.LogService;

/**
 * Uitility for finding a class.
 *
 * @author $Author: sgalland$
 * @version $FullVersion$
 * @mavengroupid $GroupId$
 * @mavenartifactid $ArtifactId$
 * @since 0.4.2
 */
public final class ClassFinder {

    private ClassFinder() {
        //
    }

    /**
     * Find the class with a search policy.
     *
     * @param classname the name of the class.
     * @return the class.
     */
    public static Class<?> findClass(String classname) {
		Class<?> type = null;
		final ClassLoader loader = ClassLoaderFinder.findClassLoader();
		if (loader != null) {
			try {
				type = loader.loadClass(classname);
			} catch (ClassNotFoundException e) {
				//
			}
		}
		if (type == null) {
			try {
				type = ClassFinder.class.getClassLoader().loadClass(classname);
			} catch (ClassNotFoundException e) {
				//
			}
		}
		if (type == null) {
			try {
				type = Class.forName(classname);
			} catch (ClassNotFoundException e) {
				//
			}
		}
		if (type != null && !LogService.class.isAssignableFrom(type)) {
			return type;
		}
		return null;
    }

}
